Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(224)

Unified Diff: ui/display/manager/display_manager.h

Issue 2540383002: Updates display manager and display preferences to handle touch calibration data. (Closed)
Patch Set: Merge with ToT Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/display/manager/display_manager.h
diff --git a/ui/display/manager/display_manager.h b/ui/display/manager/display_manager.h
index 6b58000c1b37bcd2d732ecf2f6eab4db3a802323..8437a3f1e9e944df527412bb6ddd7258351f0e93 100644
--- a/ui/display/manager/display_manager.h
+++ b/ui/display/manager/display_manager.h
@@ -164,15 +164,19 @@ class DISPLAY_MANAGER_EXPORT DisplayManager
bool SetDisplayMode(int64_t display_id,
const scoped_refptr<ManagedDisplayMode>& display_mode);
- // Register per display properties. |overscan_insets| is null if the display
- // has no custom overscan insets.
- void RegisterDisplayProperty(int64_t display_id,
- Display::Rotation rotation,
- float ui_scale,
- const gfx::Insets* overscan_insets,
- const gfx::Size& resolution_in_pixels,
- float device_scale_factor,
- ui::ColorCalibrationProfile color_profile);
+ // Register per display properties.
+ // |overscan_insets| is null if the display has no custom overscan insets.
+ // |touch_calibration_data| is null if the display has no touch calibration
+ // associated data.
+ void RegisterDisplayProperty(
+ int64_t display_id,
+ Display::Rotation rotation,
+ float ui_scale,
+ const gfx::Insets* overscan_insets,
+ const gfx::Size& resolution_in_pixels,
+ float device_scale_factor,
+ ui::ColorCalibrationProfile color_profile,
+ const TouchCalibrationData* touch_calibration_data);
// Register stored rotation properties for the internal display.
void RegisterDisplayRotationProperties(bool rotation_lock,
@@ -295,6 +299,11 @@ class DISPLAY_MANAGER_EXPORT DisplayManager
#if defined(OS_CHROMEOS)
void SetSoftwareMirroring(bool enabled) override;
bool SoftwareMirroringEnabled() const override;
+ void SetTouchCalibrationData(
+ int64_t display_id,
+ const TouchCalibrationData::CalibrationPointPairQuad& point_pair_quad,
+ const gfx::Size& display_bounds);
+ void ClearTouchCalibrationData(int64_t display_id);
#endif
// Sets/gets default multi display mode.
« no previous file with comments | « chrome/browser/chromeos/display/display_preferences_unittest.cc ('k') | ui/display/manager/display_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698